

**************************************************************************************
* User needs to change XX to appropriate location
**************************************************************************************

global data  "XX"
cd "XX"

drop if period<1


*******************************************
*distribution of clicks - FIGURE 1
*******************************************

local name a1
histogram clicks if type==1, discrete kdensity  ///
legend(off) ylabel(0(0.05)0.1) xlabel(0(20)100) scheme(s1color) name(`name',replace)
local name a2
histogram clicks if type==2, discrete kdensity  ///
legend(off) ytitle("") ylabel(0(0.05)0.1) xlabel(0(20)100) scheme(s1color) name(`name',replace)
local name a3
histogram clicks if type==3, discrete kdensity  ///
legend(off) ytitle("") ylabel(0(0.05)0.1) xlabel(0(20)100) scheme(s1color) name(`name',replace)
graph combine a1 a2 a3, scheme(s1color) cols(3)

local name a4
histogram clicks if type==4, discrete kdensity  ///
legend(off) ylabel(0(0.05)0.1)  xlabel(0(20)100) scheme(s1color) name(`name',replace)
local name a5
histogram clicks if type==5, discrete kdensity  ///
legend(off) ytitle("") ylabel(0(0.05)0.1) xlabel(0(20)100) scheme(s1color) name(`name',replace)
local name a6
histogram clicks if type==6, discrete kdensity  ///
legend(off) ytitle("") ylabel(0(0.05)0.1) xlabel(0(20)100) scheme(s1color) name(`name',replace)
graph combine a4 a5 a6, scheme(s1color) cols(3)

***************************************
*overall production function - FIGURE 2
***************************************
twoway (scatter balls clicks if type==1, msymbol(T) msize(small))  ///
(scatter balls clicks if type==2, msymbol(S) msize(small))  ///
(scatter balls clicks if type==3, msymbol(D) msize(small))  ///
(scatter balls clicks if type==4, msymbol(Th) msize(small))  ///
(scatter balls clicks if type==5, msymbol(Sh) msize(small))  ///
(scatter balls clicks if type==6, msymbol(Dh) msize(small))  ///
(fpfitci balls clicks) ///
,scheme(s1color) ylabel(0(10)50)  ytitle("catches") ///
legend(pos(5) ring(0) label(1 "(10, 0)") label(2 "(10, 5)") label(3 "(10, 10)") ///
label(4 "(20, 0)") label(5 "(20, 5)") label(6 "(20, 10)"))

*****************************
*point predictions - FIGURE 3
*****************************
local name a1
histogram clicks if type==3, discrete kdensity addplot(pci 0.1 8 0 8 "8",recast(pccapsym) msymbol(i) lcolor(red)) ///
legend(off) ylabel(0(0.05)0.1) xlabel(0(20)100) title("C/P = 1") scheme(s1color) name(`name',replace)
local name a2
histogram clicks if type==2 | type==6, discrete kdensity addplot(pci 0.1 20 0 20 "20",recast(pccapsym) msymbol(i) lcolor(red)) ///
legend(off) ytitle("") ylabel(0(0.05)0.1) xlabel(0(20)100) title("C/P = 1/2") scheme(s1color) name(`name',replace)
local name a3
histogram clicks if type==5 , discrete kdensity addplot(pci 0.1 34 0 34 "34",recast(pccapsym) msymbol(i) lcolor(red)) ///
legend(off) ytitle("") ylabel(0(0.05)0.1) xlabel(0(20)100) title("C/P = 1/4") scheme(s1color) name(`name',replace)
local name a4
histogram clicks if type==1 | type==4, discrete kdensity addplot(pci 0.1 57 0 57 "57",recast(pccapsym) msymbol(i) lcolor(red)) ///
legend(off) ytitle("") ylabel(0(0.05)0.1) xlabel(0(20)100) title("C/P = 0") scheme(s1color) name(`name',replace)
graph combine a1 a2 a3 a4, scheme(s1color) cols(4)


*********************************
*Panel data regressions - TABLE 1
*********************************
gen balls1=balls/(clicks^0.5)
gen clicks10=1/(clicks^0.5)
gen clicks20=clicks^(0.5)/(clicks^0.5)
gen clicks30=clicks^2/(clicks^0.5)

// FULL
xtreg balls1 clicks10 clicks20 clicks30 i.period, i(sub) mle nocon

// PRIZE=10
xtreg balls1 clicks10 clicks20 clicks30 i.period if type<=3, i(sub) mle nocon

// PRIZE=20
xtreg balls1 clicks10 clicks20 clicks30 i.period if type>3, i(sub) mle nocon




*********************************
*descriptive statistics - TABLE 2
*********************************
clear

table type, c(mean clicks sd clicks)
table type, c(mean balls sd balls)

//BY SESSIONS
table type if sub<300, c(mean clicks sd clicks)
table type if sub>300, c(mean clicks sd clicks)


********************************
*test stability across treatments
********************************
gen t1= (type<4)

xtreg balls1 clicks10 clicks20 clicks30 i.period, i(sub) mle nocon
estimates store full
xtreg balls1 c.(clicks10 clicks20 clicks30)#t1 i.period, i(sub) mle nocon
lrtest full

// FIGURE
gen f=10.4766 + 5.401946 *clicks^0.5 -.0029592*clicks^2 if t1==1
replace f=9.404566 + 5.659943 *clicks^0.5 -.0034576*clicks^2 if t1==0
twoway (line f clicks if type<4,sort) ///
(line f clicks if type>3,sort lpattern(dash)) ///
,scheme(s1color) ylabel(0(10)50)  ytitle("catches") ///
legend(pos(5) ring(0) label(1 "P=10") label(2 "P=20"))


*********************************
*test stability over two sessions
*********************************
gen session=(subject<=300)
xtreg balls1 clicks10 clicks20 clicks30 i.period, i(sub) mle nocon
estimates store full
xtreg balls1 c.(clicks10 clicks20 clicks30)#session i.period, i(sub) mle nocon
lrtest full

// FIGURE
gen f1=10.54392 + 5.315308 *clicks^0.5 -.0030525*clicks^2 if session==1
replace f1=9.730237 + 5.650206 *clicks^0.5 -.0032235*clicks^2 if session==0
twoway (line f1 clicks if session==1,sort) ///
(line f1 clicks if session==0,sort lpattern(dash)) ///
,scheme(s1color) ylabel(0(10)50)  ytitle("catches") ///
legend(pos(5) ring(0) label(1 "Session 1") label(2 "Session 2"))







